@@ -4,6 +4,7 @@ import pprint
 import random
 import re
 import tempfile
+from collections.abc import Iterable
 from math import isclose, isnan
 
 import markdown
@@ -395,6 +396,124 @@ class PythonGrader(BaseGrader):
         else:
             return
 
+    def grade_number(self, tolerance=0, return_bool=False):
+        """Evaluate student's submitted number (int or float).
+
+        Parameters
+        ----------
+        tolerance: int or float, default=0.0
+            For numerical values, what is the maximum allowed
+            difference between ``submission`` and ``answer``? If ``tolerance=0.1``, values must be
+            identical. If ``tolerance=0.1``, values must be within 10% of each
+            other (relative to the larger absolute value of the two).
+
+        return_bool : bool, default=False
+            Whether to return ``self.passed`` once grading is complete. You'll need this if
+            you want to design your own grading workflow beyond the default.
+        """
+        if not isclose(self.submission, self.answer, rel_tol=tolerance):
+            self.update_comment(
+                f"Your submission `{self.submission}` doesn't match the expected result."
+            )
+            return False if return_bool else self.return_feedback()
+
+        self.add_to_score()
+        return True if return_bool else self.return_feedback()
+
+    def grade_bool(self, return_bool=False):
+        """Evaluate student's submitted number (int or float).
+
+        Parameters
+        ----------
+        return_bool : bool, default=False
+            Whether to return ``self.passed`` once grading is complete. You'll need this if
+            you want to design your own grading workflow beyond the default.
+        """
+        if self.submission != self.answer:
+            self.update_comment(
+                f"Your submission `{self.submission}` doesn't match the expected result."
+            )
+            return False if return_bool else self.return_feedback()
+
+        self.add_to_score()
+        return True if return_bool else self.return_feedback()
+
+    def grade_string(
+        self, ignore_case=False, contains=None, return_bool=False
+    ):
+        """Evaluate student's submitted string.
+
+        By default, evaluates for an exact match. If ``contains`` is specified, method
+        will only match for that term (or terms).
+
+        Parameters
+        ----------
+        ignore_case: bool, default=False
+            Whether or not to ignore case when evaluating submission.
+
+        contains: str or list, default=None
+            If ``None``, submission will be evaluated for an exact match. If ``str``,
+            will only match that substring. If ``list``, will match all items.
+
+        return_bool : bool, default=False
+            Whether to return ``self.passed`` once grading is complete. You'll need this if
+            you want to design your own grading workflow beyond the default.
+
+        Examples
+        --------
+        >>> g = PythonGrader(submission="Hello world", answer="Hello world")
+        >>> g.grade_string(ignore_case=False, return_bool=True)
+        True
+
+        >>> g = PythonGrader(submission="Hello world", answer="")
+        >>> g.grade_string(contains="WORLD", ignore_case=True, return_bool=True)
+        True
+
+        Note that when you specify ``contains``, the answer can be an empty string.
+
+        >>> g = PythonGrader(submission="Hello world", answer="")
+        >>> g.grade_string(contains=["Hello", "monkey"], ignore_case=False, return_bool=True)
+        False
+        >>> print(g.comment)
+        Your submission is missing an important term: `'monkey'`.
+
+        """
+        if not isinstance(self.submission, str):
+            raise TypeError(
+                f"grade_string method can only be used with str submissions, not {type(self.submission).__name__}."
+            )
+
+        if ignore_case:
+            self.submission = self.submission.lower()
+            self.answer = self.answer.lower()
+            if isinstance(contains, str):
+                contains = contains.lower()
+            if isinstance(contains, Iterable):
+                contains = [str(s).lower() for s in list(contains)]
+
+        if (not contains) and (self.submission != self.answer):
+            self.update_comment(
+                "Your submission doesn't match the expected result"
+            )
+            return False if return_bool else self.return_feedback()
+
+        if (isinstance(contains, str)) and contains not in self.submission:
+            self.update_comment(
+                f"Your submission is missing an important term: `'{contains}'`."
+            )
+            return False if return_bool else self.return_feedback()
+
+        if isinstance(contains, Iterable):
+            for s in list(contains):
+                if str(s) not in self.submission:
+                    self.update_comment(
+                        f"Your submission is missing an important term: `'{s}'`."
+                    )
+                    return False if return_bool else self.return_feedback()
+
+        self.add_to_score()
+        return True if return_bool else self.return_feedback()
+
 
 class PandasGrader(BaseGrader):
     """Grader for evaluating objects from `pandas <https://pandas.pydata.org/docs/index.html>`_. library."""
@@ -451,6 +570,7 @@ class PandasGrader(BaseGrader):
         sort_values_by=None,
         match_index=True,
         match_index_col_order=False,
+        match_colnames_only=False,
         tolerance=0.01,
         return_bool=False,
     ):
@@ -471,6 +591,10 @@ class PandasGrader(BaseGrader):
             Whether or not to consider the order of the index and columns in the
             submitted DataFrame.
 
+        match_colnames_only : bool, default=False
+            If ``True`` only column names will be evaluated, not index labels or
+            DataFrame values. Note that the index and column order will always be ignored.
+
         tolerance: int or float, default=0.01
             For numerical values, what is the maximum allowed
             difference between ``submission`` and ``answer``? If ``tolerance=0.1``, values must be
@@ -542,6 +666,16 @@ class PandasGrader(BaseGrader):
             self.submission = self.submission.reset_index(drop=True)
             self.answer = self.answer.reset_index(drop=True)
 
+        if match_colnames_only:
+            for c in self.answer.columns:
+                if c not in self.submission.columns:
+                    self.update_comment(
+                        f"Your submission is missing a `'{c}'` column."
+                    )
+                    return False if return_bool else self.return_feedback()
+            self.add_to_score()
+            return True if return_bool else self.return_feedback()
+
         # Check shape
         if self.submission.shape != self.answer.shape:
             self.update_comment(
